==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/kea-CV.pl <==
{
  am_pm_abbreviated => [
    "am",
    "pm",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d 'di' MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d 'di' MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a (v)",
    hmv => "h:mm a (v)",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM 'di' y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'di' y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kea-CV",
  date_format_full => "EEEE, d 'di' MMMM 'di' y",
  date_format_long => "d 'di' MMMM 'di' y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "sig",
    "ter",
    "kua",
    "kin",
    "ses",
    "sab",
    "dum",
  ],
  day_format_narrow => [
    "S",
    "T",
    "K",
    "K",
    "S",
    "S",
    "D",
  ],
  day_format_wide => [
    "sigunda-fera",
    "tersa-fera",
    "kuarta-fera",
    "kinta-fera",
    "sesta-fera",
    "sabadu",
    "dumingu",
  ],
  day_stand_alone_abbreviated => [
    "sig",
    "ter",
    "kua",
    "kin",
    "ses",
    "sab",
    "dum",
  ],
  day_stand_alone_narrow => [
    "S",
    "T",
    "K",
    "K",
    "S",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "sigunda-fera",
    "tersa-fera",
    "kuarta-fera",
    "kinta-fera",
    "sesta-fera",
    "s\N{U+00e1}badu",
    "dumingu",
  ],
  era_abbreviated => [
    "AK",
    "DK",
  ],
  era_narrow => [
    "AK",
    "DK",
  ],
  era_wide => [
    "Antis di Kristu",
    "Dispos di Kristu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kabuverdianu",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "Mai",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Otu",
    "Nuv",
    "Diz",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janeru",
    "Febreru",
    "Marsu",
    "Abril",
    "Maiu",
    "Junhu",
    "Julhu",
    "Agostu",
    "Setenbru",
    "Otubru",
    "Nuvenbru",
    "Dizenbru",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "Mai",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Otu",
    "Nuv",
    "Diz",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janeru",
    "Febreru",
    "Marsu",
    "Abril",
    "Maiu",
    "Junhu",
    "Julhu",
    "Agostu",
    "Setenbru",
    "Otubru",
    "Nuvenbru",
    "Dizenbru",
  ],
  name => "Kabuverdianu Cape Verde",
  native_language => "kabuverdianu",
  native_name => "kabuverdianu Kabu Verdi",
  native_script => undef,
  native_territory => "Kabu Verdi",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+00ba} trimestri",
    "2\N{U+00ba} trimestri",
    "3\N{U+00ba} trimestri",
    "4\N{U+00ba} trimestri",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+00ba} trimestri",
    "2\N{U+00ba} trimestri",
    "3\N{U+00ba} trimestri",
    "4\N{U+00ba} trimestri",
  ],
  script => undef,
  territory => "Cape Verde",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/kea-CV.pl <==
{
  am_pm_abbreviated => [
    "am",
    "pm",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E, h:mm B",
    EBhms => "E, h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d 'di' MMMM",
    "MMMMW-count-other" => "W'\N{U+00ba}' 'simana' 'di' MMMM",
    MMMMd => "d 'di' MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a (v)",
    hmv => "h:mm a (v)",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "LL/y",
    yMEd => "E, dd/MM/y",
    yMM => "LL/y",
    yMMM => "LLL y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL 'di' y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'di' y",
    "yw-count-other" => "w'\N{U+00ba}' 'simana' 'di' Y",
  },
  code => "kea-CV",
  date_format_full => "EEEE, d 'di' MMMM 'di' y",
  date_format_long => "d 'di' MMMM 'di' y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "sig",
    "ter",
    "kua",
    "kin",
    "ses",
    "sab",
    "dum",
  ],
  day_format_narrow => [
    "S",
    "T",
    "K",
    "K",
    "S",
    "S",
    "D",
  ],
  day_format_wide => [
    "sigunda-fera",
    "tersa-fera",
    "kuarta-fera",
    "kinta-fera",
    "sesta-fera",
    "sabadu",
    "dumingu",
  ],
  day_stand_alone_abbreviated => [
    "sig",
    "ter",
    "kua",
    "kin",
    "ses",
    "sab",
    "dum",
  ],
  day_stand_alone_narrow => [
    "S",
    "T",
    "K",
    "K",
    "S",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "sigunda-fera",
    "tersa-fera",
    "kuarta-fera",
    "kinta-fera",
    "sesta-fera",
    "s\N{U+00e1}badu",
    "dumingu",
  ],
  era_abbreviated => [
    "AK",
    "DK",
  ],
  era_narrow => [
    "AK",
    "DK",
  ],
  era_wide => [
    "antis di Kristu",
    "dispos di Kristu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kabuverdianu",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "Mai",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Otu",
    "Nuv",
    "Diz",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janeru",
    "Febreru",
    "Marsu",
    "Abril",
    "Maiu",
    "Junhu",
    "Julhu",
    "Agostu",
    "Setenbru",
    "Otubru",
    "Nuvenbru",
    "Dizenbru",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "Mai",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Otu",
    "Nuv",
    "Diz",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janeru",
    "Febreru",
    "Marsu",
    "Abril",
    "Maiu",
    "Junhu",
    "Julhu",
    "Agostu",
    "Setenbru",
    "Otubru",
    "Nuvenbru",
    "Dizenbru",
  ],
  name => "Kabuverdianu Cape Verde",
  native_language => "kabuverdianu",
  native_name => "kabuverdianu Kabu Verdi",
  native_script => undef,
  native_territory => "Kabu Verdi",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+00ba} trimestri",
    "2\N{U+00ba} trimestri",
    "3\N{U+00ba} trimestri",
    "4\N{U+00ba} trimestri",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+00ba} trimestri",
    "2\N{U+00ba} trimestri",
    "3\N{U+00ba} trimestri",
    "4\N{U+00ba} trimestri",
  ],
  script => undef,
  territory => "Cape Verde",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}
